@@ -192,7 +192,7 @@ static PyObject *getChromSize(PyObject *self,PyObject *args)
 	}
 	PyObject *rslt = PyTuple_New(2);
 	PyTuple_SetItem(rslt, 0, chroms);
-	PyTuple_SetItem(rslt, 1, chroms);
+	PyTuple_SetItem(rslt, 1, sizes);
 	return rslt;
 }
 
