@@ -1,5 +1,5 @@
 #!/usr/bin/python
-#Last-modified: 05 Oct 2013 09:45:17 AM
+#Last-modified: 20 Jun 2014 10:04:46 AM
 
 #         Module/Scripts Description
 # 
@@ -41,6 +41,6 @@ from ngslib import IO
 if __name__=="__main__":
     if len(sys.argv)==1:
         sys.exit("Example:"+sys.argv[0]+" *.tab >*.bed ")
-    for item in IO.BioReader(sys.argv[1],ftype='tab'):
+    for item in IO.BioReader(sys.argv[1],ftype='genepred'):
         print item.toBed()
 
